==> xoops-2.5.0.tbz: www/xoops/htdocs/modules/system/language/english/admin/comments.php <==
<?php
/**
 * @copyright   The XOOPS Project http://sourceforge.net/projects/xoops/
 * @license     http://www.fsf.org/copyleft/gpl.html GNU public license
 * _LANGCODE    en
 * _CHARSET     UTF-8
 * @version     $Id: comments.php 5566 2010-10-20 11:45:26Z beckmi $
 */
 
// Manager
define("_AM_SYSTEM_COMMENTS_NAV_MANAGER","Comment Manager");
define("_AM_SYSTEM_COMMENTS_NAV_MAIN","List");
define("_AM_SYSTEM_COMMENTS_NAV_PURGE","Purge");

// Nav
define("_AM_SYSTEM_COMMENTS_MODULE_ADMIN","Modules Administration");

// Tips
define("_AM_SYSTEM_COMMENTS_NAV_TIPS","
<ul>
<li>Manage comments for all your modules.</li>
<li>Delete comments easily with the purge.</li>
</ul>");

// Form
define("_AM_SYSTEM_COMMENTS_FORM_LIST_COMMENTS","List Comments");
define("_AM_SYSTEM_COMMENTS_FORM_ALL_MODS","All modules");
define("_AM_SYSTEM_COMMENTS_FORM_ALL_STATUS","Any status");

define("_AM_SYSTEM_COMMENTS_FORM_PURGE","Purge");
define("_AM_SYSTEM_COMMENTS_FORM_PURGE_DATE_AFTER","After this date (white for any date)");
define("_AM_SYSTEM_COMMENTS_FORM_PURGE_DATE_BEFORE","Before this date (white for any date)");
define("_AM_SYSTEM_COMMENTS_FORM_PURGE_GROUPS","Groups");
define("_AM_SYSTEM_COMMENTS_FORM_PURGE_USER","Nickname of the user");
define("_AM_SYSTEM_COMMENTS_FORM_PURGE_STATUS","Status");
define("_AM_SYSTEM_COMMENTS_FORM_PURGE_MODULES","Modules");

// Tab
define("_AM_SYSTEM_COMMENTS_TITLE","Title");
define("_AM_SYSTEM_COMMENTS_POSTED","Posted");
define("_AM_SYSTEM_COMMENTS_IP","IP");
define("_AM_SYSTEM_COMMENTS_MODULE","Module");
define("_AM_SYSTEM_COMMENTS_STATUS","Status");
define("_AM_SYSTEM_COMMENTS_ACTION","Action");
define("_AM_SYSTEM_COMMENTS_VIEW","See comment");

define("_AM_SYSTEM_COMMENTS_NO_COMMENTS","No comments");
define("_AM_SYSTEM_COMMENTS_COMMENTS_FOUND","%s comment(s) found.");



?>

==> xoops-2.5.5.tbz: www/xoops/htdocs/modules/system/language/english/admin/comments.php <==
<?php
/**
 * @copyright   The XOOPS Project http://sourceforge.net/projects/xoops/
 * @license     http://www.fsf.org/copyleft/gpl.html GNU public license
 * _LANGCODE    en
 * _CHARSET     UTF-8
 * @version     $Id: comments.php 9292 2012-04-09 20:43:53Z beckmi $
 */
 
// Manager
define("_AM_SYSTEM_COMMENTS_NAV_MANAGER","Comment Management");
define("_AM_SYSTEM_COMMENTS_NAV_MAIN","List");
define("_AM_SYSTEM_COMMENTS_NAV_PURGE","Purge");

// Nav
define("_AM_SYSTEM_COMMENTS_MODULE_ADMIN","Modules Administration");

// Tips
define("_AM_SYSTEM_COMMENTS_NAV_TIPS","
<ul>
<li>Manage comments for all your modules.</li>
<li>Delete comments easily with the purge.</li>
</ul>");

// Form
define("_AM_SYSTEM_COMMENTS_FORM_LIST_COMMENTS","List Comments");
define("_AM_SYSTEM_COMMENTS_FORM_ALL_MODS","All modules");
define("_AM_SYSTEM_COMMENTS_FORM_ALL_STATUS","Any status");

define("_AM_SYSTEM_COMMENTS_FORM_PURGE","Purge");
define("_AM_SYSTEM_COMMENTS_FORM_PURGE_DATE_AFTER","After this date (leave empty for any date)");
define("_AM_SYSTEM_COMMENTS_FORM_PURGE_DATE_BEFORE","Before this date (leave empty for any date)");
define("_AM_SYSTEM_COMMENTS_FORM_PURGE_GROUPS","Groups");
define("_AM_SYSTEM_COMMENTS_FORM_PURGE_USER","User name");
define("_AM_SYSTEM_COMMENTS_FORM_PURGE_STATUS","Status");
define("_AM_SYSTEM_COMMENTS_FORM_PURGE_MODULES","Modules");

// Tab
define("_AM_SYSTEM_COMMENTS_TITLE","Title");
define("_AM_SYSTEM_COMMENTS_POSTED","Author");
define("_AM_SYSTEM_COMMENTS_IP","IP");
define("_AM_SYSTEM_COMMENTS_MODULE","Module");
define("_AM_SYSTEM_COMMENTS_STATUS","Status");
define("_AM_SYSTEM_COMMENTS_ACTION","Action");
define("_AM_SYSTEM_COMMENTS_VIEW","See comment");

define("_AM_SYSTEM_COMMENTS_NO_COMMENTS","No comments");
define("_AM_SYSTEM_COMMENTS_COMMENTS_FOUND","%s comment(s) found.");



?>
